@@ -18,7 +18,7 @@ from calculate.consolegui import qt
 import urllib2
 from calculate.lib.utils.tools import Locker
 
-from more import show_msg, LabelWordWrap, get_ip_mac, get_sid
+from more import show_msg, LabelWordWrap, get_ip_mac, get_sid, get_icon
 
 def client_sid(sid, client, cert_id, lang):
     """ get number session from server and write this in file """
@@ -133,7 +133,7 @@ class ViewSessionInfo (qt.QWidget):
         self.setFixedSize(260,200)
         self.setLayout(self.layout)
 
-        self.setWindowIcon(qt.QIcon.fromTheme("document-edit-verify"))
+        self.setWindowIcon(get_icon("document-edit-verify"))
         self.setWindowTitle(_('Session information'))
 
         self.move(window.geometry().x() + window.geometry().width() / 2 \
